@@ -1,6 +1,7 @@
 from dvc.output.base import BaseOutput
-from dvc.remote.hdfs import HDFSRemote
+
+from ..tree.hdfs import HDFSRemoteTree
 
 
 class HDFSOutput(BaseOutput):
-    REMOTE = HDFSRemote
+    TREE_CLS = HDFSRemoteTree
