@@ -1,7 +1,7 @@
 from dvc.output.base import BaseOutput
-from dvc.remote.ssh import SSHRemote, SSHRemoteTree
+
+from ..tree.ssh import SSHRemoteTree
 
 
 class SSHOutput(BaseOutput):
-    REMOTE_CLS = SSHRemote
     TREE_CLS = SSHRemoteTree
